# ScriptName: Create-SBSEGroups.ps1
#
# Script to create missing SBSE groups in a migration scenario
#    and add the 500 account (Administrator) from SBS 2003
#    to the SBSE Groups
#
# Uses: ActiveDirectory Module
#
# Created: 15/05/2011 by Charlie Russel
# ModHist: 
#
# Copyright 2011 by Charlie Russel & Sharon Crawford. All rights reserved.
#   You may freely use this script in your own environment, 
#   modifying it to meet your needs. 
#   You may not, however, re-publish it without express permission, 
#   and must, in all cases, provide attribution to the copyright holders.
# 
Import-Module ActiveDirectory

# Modify the next line to use the correct Domain Name for your SBS Domain
$DomainName = "Example"

# If you've modified the name for the 500 account, change this next line
$AdminUser  = "Administrator"

# Create a list of SBS Essentials groups to create
$GrpList = "RA_AllowAddInAccess",`
           "RA_AllowComputerAccess",`
           "RA_AllowDashboardAccess",`
           "RA_AllowHomePageLinks",`
           "RA_AllowNetworkAlertAccess",`
           "RA_AllowRemoteAccess",`
           "RA_AllowShareAccess",`
           "WSSUsers"

# Set the type of security group to create
$GrpScope = "Universal"  

# Location to create the groups
$SecGrpOU = "OU=Security Groups,OU=MyBusiness,DC=$DomainName,DC=local"

# Iterate through the list of groups and create them
ForEach ($GrpName in $GrpList) {
   New-ADGroup `
         -name             $GrpName `
         -sAMAccountName   $GrpName `
         -DisplayName      $GrpName `
         -GroupCategory    Security `
         -GroupScope       $GrpScope `
         -Description      "SBS 2011 Essentials Groups" `
         -Path             $SecGrpOU
   Add-ADGroupMember -Identity "$GrpName" -Members "Administrator"
}
